Changelog
---------

1.3.2
-----

* Update Game Image

1.3.1
-----

* Bugfix: Add click lib as pinned

1.3.0
-----

* Improve UI,
* BugFix: Robbot choice
* Create Brainiac Class

1.2.1
-----

* BugFix: Final and current shot Statistics

1.2.0
-----

* BugFix: Adding ship using same coordinates
* BugFix: Robbot using repeated coordinates


1.1.3
-----

* Add raw image to be seen on Pypi

1.1.2
-----

* Change ci to cicleCI
* Update Pypi

1.1.1
-----

* Remove debug and change travis config

1.1.0
-----

* Add tests
* Add codecov and travis integration
* Update Readme
* Remove blink from messages

1.0.0
-----

* Change game play to be Multiplayer
* Change game to finish when CPU or Player1 wins or use CTRL+C
* Refactor language to be central
* Create Custom exceptions
* Use Python Click to print the board using colors
* Use Python Click to improve the main function

0.3.13
------

* BugFix: Exit game with CTRL+C
* Move exception treatment to battlefield.py
* Create more exceptions
* Create a centralized language translator

0.3.12
------

* Improve UI to print statistics


0.3.11
------

* Update Readme

0.3.10
------

* Fix table layout

0.3.9
-----

* Refactor Main: Remove unnecessary code
* Remove duplicated code
* Add translation

0.3.8
-----

* Fix: Readme Pypi

0.3.7
-----

* Fix: Readme Pypi

0.3.6
-----

* Update readme

0.3.5
-----

* Use vertical label in upper case

0.3.4
-----

* Add more status messages

0.3.3
-----

* Fix logical

0.3.1
-----

* Add locale folder to Manifest.in

0.3.0
-----

* Add Gettext/internationalization support

0.2.0
-----

* Bug Fixes
* Improve better UI
* Fix layout
* Change to use letters instead of only numbers

0.1.0 (2019-01-01)
------------------

* initial release
